Please see [https://docs.mlcommons.org/cm4mlops/scripts/DevOps-automation/compile-program](https://docs.mlcommons.org/cm4mlops/scripts/DevOps-automation/compile-program) for the documentation of this CM script.
